[![PyPI Package](https://img.shields.io/pypi/v/oceans.svg)](https://pypi.org/project/oceans/) [![Travis Build Status](https://travis-ci.org/pyoceans/python-oceans.svg?branch=master)](https://travis-ci.org/pyoceans/python-oceans) [![DOI](https://zenodo.org/badge/11956337.svg)](https://zenodo.org/badge/latestdoi/11956337)

# Python Oceans

Misc helper functions for ocean sciences.

Most of the functions here are Python versions of some common MatlabTM functions.
They are untested and probably buggy. Use with caution!
